traits-enaml
============

Traits-Enaml is an extension library to facilitate interoperation of `Enaml
>=0.8.9` and above with `Traits` and allow a programmer to drive enaml views
using traits models, enable/chaco components and mayavi 3D scenes.

References
==========

 * Enaml:  https://github.com/nucleic/enaml
 * Traits: https://github.com/enthought/traits
 * Enable: https://github.com/enthought/enable
 * Mayavi: https://github.com/enthought/mayavi

Status
======

.. image:: https://api.travis-ci.org/enthought/traits-enaml.png?branch=master
   :target: https://travis-ci.org/enthought/traits-enaml
   :alt: Build status

.. image:: http://codecov.io/github/enthought/traits-enaml/coverage.svg?branch=master
   :target: http://codecov.io/github/enthought/traits-enaml?branch=master
   :alt: Coverage status
